==> billogram-foundation-4.4.0.tgz: package/modules/components/datepicker/DatepickerCalendar.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import moment from 'moment';
import purebem from 'purebem';

import * as lang from '../../utils/lang';
import isNullOrEmpty from '../../utils/isNullOrEmpty';

import getWeeks from './utils/getWeeks';


export default ({
    block,
    displayName
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            currentMonth: PropTypes.object,
            hasGrayedOutPast: PropTypes.bool,
            highlightedIndex: PropTypes.object,
            isDisabledDate: PropTypes.func,
            onChange: PropTypes.func,
            onNextMonthClick: PropTypes.func,
            onPreviousMonthClick: PropTypes.func,
            value: PropTypes.object
        },

        getDefaultProps() {
            const now = moment();
            return {
                currentMonth: now,
                hasGrayedOutPast: false,
                onChange: (/* value */) => {},
                onNextMonthClick: () => {},
                onPreviousMonthClick: () => {},
                highlightedIndex: now,
                isDisabledDate: (/* value */) => false,
                value: null
            };
        },

        renderMonthSelector() {
            const { onPreviousMonthClick, currentMonth, onNextMonthClick } = this.props;
            return (
                <div className={ block('calendar-month-selector') }>
                    <i className={ block('calendar-month-selector-icon', ['left', 'touchable']) } onClick={ onPreviousMonthClick } />
                    <div className={ block('calendar-month-selector-text') }>
                        { lang.pgettext('foundation-datepicker', `Month--${currentMonth.month() + 1}`) } { currentMonth.year() }
                    </div>
                    <i className={ block('calendar-month-selector-icon', ['right', 'touchable']) } onClick={ onNextMonthClick } />
                </div>
            );
        },

        renderWeek(week, index) {
            const { currentMonth, hasGrayedOutPast, highlightedIndex, isDisabledDate, onChange, value } = this.props;
            return (
                <div key={ index } className={ block('calendar-week') }>
                    {
                        week.map((day) => {
                            const newValue = day.clone();

                            const now = moment();
                            const past = hasGrayedOutPast && (day.format('YYYY-MM-DD') < now.format('YYYY-MM-DD'));
                            const outside = day.month() !== currentMonth.month();
                            const selected = value !== null && day.year() === value.year() && day.dayOfYear() === value.dayOfYear();
                            const today = (day.year() === now.year()) && (day.dayOfYear() === now.dayOfYear());
                            const highlighted = day.year() === highlightedIndex.year() && day.dayOfYear() === highlightedIndex.dayOfYear();

                            const disabled = isDisabledDate(newValue);
                            const enabled = !disabled;

                            const date = day.date();
                            return (
                                <div key={ date }
                                     className={ block('calendar-day', { disabled, enabled, outside, past, today }) }
                                     onClick={ () => onChange(newValue) }>
                                    <div className={ block('calendar-day-content', { highlighted, selected }) }>{ date }</div>
                                </div>
                            );
                        })
                    }
                </div>
            );
        },

        renderWeeks() {
            const { currentMonth } = this.props;
            const weeks = getWeeks(currentMonth);

            return (
                <div className={ block('calendar-month') }>
                    <div className={ block('calendar-week') }>
                        {
                            ['mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun'].map((weekday) => {
                                return (
                                    <div key={ weekday } className={ block('calendar-weekday') }>
                                        { lang.pgettext('foundation-datepicker', `WeekdayHeader--${weekday}`) }
                                    </div>
                                );
                            })
                        }
                    </div>
                    <hr className={ block('calendar-weekday-separator') } />
                    { weeks.map((week, index) => this.renderWeek(week, index)) }
                </div>
            );
        },

        render() {
            return (
                <div className={ purebem.many(block('calendar'), 'ignore-react-onclickoutside') }>
                    { this.renderMonthSelector() }
                    { this.renderWeeks() }
                </div>
            );
        }

    });

};

==> billogram-foundation-4.8.1.tgz: package/modules/components/datepicker/DatepickerCalendar.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';
import moment from 'moment';
import purebem from 'purebem';

import * as lang from '../../utils/lang';
import isNullOrEmpty from '../../utils/isNullOrEmpty';

import getWeeks from './utils/getWeeks';


export default ({
    block,
    displayName,
}) => {

    invariant(block !== undefined, 'Missing purebem block');
    invariant(!isNullOrEmpty(displayName), 'Missing display name');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            currentMonth: PropTypes.object,
            hasGrayedOutPast: PropTypes.bool,
            highlightedIndex: PropTypes.object,
            isDisabledDate: PropTypes.func,
            onChange: PropTypes.func,
            onNextMonthClick: PropTypes.func,
            onPreviousMonthClick: PropTypes.func,
            value: PropTypes.object,
        },

        getDefaultProps() {
            const now = moment();
            return {
                currentMonth: now,
                hasGrayedOutPast: false,
                onChange: (/* value */) => {},
                onNextMonthClick: () => {},
                onPreviousMonthClick: () => {},
                highlightedIndex: now,
                isDisabledDate: (/* value */) => false,
                value: null,
            };
        },

        renderMonthSelector() {
            const { onPreviousMonthClick, currentMonth, onNextMonthClick } = this.props;
            return (
                <div className={ block('calendar-month-selector') }>
                    <i className={ block('calendar-month-selector-icon', ['left', 'touchable']) } onClick={ onPreviousMonthClick } />
                    <div className={ block('calendar-month-selector-text') }>
                        { lang.pgettext('foundation-datepicker', `Month--${currentMonth.month() + 1}`) } { currentMonth.year() }
                    </div>
                    <i className={ block('calendar-month-selector-icon', ['right', 'touchable']) } onClick={ onNextMonthClick } />
                </div>
            );
        },

        renderWeek(week, index) {
            const { currentMonth, hasGrayedOutPast, highlightedIndex, isDisabledDate, onChange, value } = this.props;
            return (
                <div key={ index } className={ block('calendar-week') }>
                    {
                        week.map((day) => {
                            const newValue = day.clone();

                            const now = moment();
                            const past = hasGrayedOutPast && (day.format('YYYY-MM-DD') < now.format('YYYY-MM-DD'));
                            const outside = day.month() !== currentMonth.month();
                            const selected = value !== null && day.year() === value.year() && day.dayOfYear() === value.dayOfYear();
                            const today = (day.year() === now.year()) && (day.dayOfYear() === now.dayOfYear());
                            const highlighted = day.year() === highlightedIndex.year() && day.dayOfYear() === highlightedIndex.dayOfYear();

                            const disabled = isDisabledDate(newValue);
                            const enabled = !disabled;

                            const date = day.date();
                            return (
                                <div key={ date }
                                     className={ block('calendar-day', { disabled, enabled, outside, past, today }) }
                                     onClick={ () => onChange(newValue) }>
                                    <div className={ block('calendar-day-content', { highlighted, selected }) }>{ date }</div>
                                </div>
                            );
                        })
                    }
                </div>
            );
        },

        renderWeeks() {
            const { currentMonth } = this.props;
            const weeks = getWeeks(currentMonth);

            return (
                <div className={ block('calendar-month') }>
                    <div className={ block('calendar-week') }>
                        {
                            ['mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun'].map((weekday) => {
                                return (
                                    <div key={ weekday } className={ block('calendar-weekday') }>
                                        { lang.pgettext('foundation-datepicker', `WeekdayHeader--${weekday}`) }
                                    </div>
                                );
                            })
                        }
                    </div>
                    <hr className={ block('calendar-weekday-separator') } />
                    { weeks.map((week, index) => this.renderWeek(week, index)) }
                </div>
            );
        },

        render() {
            return (
                <div className={ purebem.many(block('calendar'), 'ignore-react-onclickoutside') }>
                    { this.renderMonthSelector() }
                    { this.renderWeeks() }
                </div>
            );
        },

    });

};
